@@ -2,7 +2,7 @@ package Mojolicious::Plugin::TtRenderer::Engine;
 
 use warnings;
 use strict;
-use v5.10;
+use 5.010001;
 use base 'Mojo::Base';
 use Carp ();
 use File::Spec ();
@@ -13,7 +13,7 @@ use Scalar::Util 'weaken';
 use POSIX ':errno_h';
 
 # ABSTRACT: Template Toolkit renderer for Mojolicious
-our $VERSION = '1.56'; # VERSION
+our $VERSION = '1.60'; # VERSION
 
 __PACKAGE__->attr('tt');
 
@@ -35,7 +35,7 @@ sub _init {
     if($dir=$args{cache_dir}) {
 
       if($app && substr($dir,0,1) ne '/') {
-        $dir=$app->home->rel_dir($dir);
+        $dir=$app->home->rel_file($dir);
       }
     }
 
@@ -86,9 +86,6 @@ sub _render {
 
     my $helper = Mojolicious::Plugin::TtRenderer::Helper->new(ctx => $c);
 
-    # Purge previous result
-    $$output = '';
-
     # fixes for t/lite_app_with_default_layouts.t
     unless ($c->stash->{layout}) {
         $c->stash->{content} ||= $c->stash->{'mojo.content'}->{content};
@@ -110,10 +107,10 @@ sub _render {
                 $self->tt->process($ret[0], @params);
             }
             elsif (not defined $ret[0]) { # not found
-                return 0;
+                return;
             }
             else { # error
-                return 0 if $! == ENOENT && (not ref $ret[0]); # not found when not blessed exception
+                return if $! == ENOENT && (not ref $ret[0]); # not found when not blessed exception
                 die $ret[0];
             }
         }
@@ -121,8 +118,6 @@ sub _render {
 
     # Error
     die $self->tt->error unless $ok;
-
-    1;
 }
 
 1;    # End of Mojolicious::Plugin::TtRenderer::Engine
@@ -184,7 +179,7 @@ sub options       { @_ > 1 ? $_[0]->{options}       = $_[1] : $_[0]->{options} }
 
 sub _template_modified {
     my($self, $template) = @_;
-    $self->SUPER::_template_modified($template) || $template =~ /^templates(?:\/|\\)/;
+    $self->SUPER::_template_modified($template) || $template =~ /^templates(?:\/|\\)/ || undef;
 }
 
 sub _template_content {
@@ -235,7 +230,7 @@ Mojolicious::Plugin::TtRenderer::Engine - Template Toolkit renderer for Mojolici
 
 =head1 VERSION
 
-version 1.56
+version 1.60
 
 =head1 SYNOPSIS
 
@@ -278,6 +273,8 @@ come with Mojolicious.
 =for stopwords Bjørn
 Szász
 Árpád
+Романов
+Сергей
 
 =head1 RENDERING
 
@@ -336,8 +333,6 @@ L<Mojolicious>,
 L<Mojolicious::Guides>, 
 L<http://mojolicious.org>.
 
-=cut
-
 =head1 AUTHOR
 
 Original author: Ask Bjørn Hansen
@@ -378,9 +373,11 @@ uwisser
 
 Dinis Lage
 
+jay mortensen (GMORTEN)
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Ask Bjørn Hansen.
+This software is copyright (c) 2009-2018 by Ask Bjørn Hansen.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
